# This file was auto-generated by Fern from our API Definition.

import typing

ModerationStatusResponseModelSafetyStatus = typing.Union[
    typing.Literal["appeal_approved", "appeal_denied", "false_positive"], typing.Any
]
