# This file was auto-generated by Fern from our API Definition.

import typing

BodyCreatePodcastV1StudioPodcastsPostDurationScale = typing.Union[
    typing.Literal["short", "default", "long"], typing.Any
]
