# This file was auto-generated by Fern from our API Definition.

import typing

BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostWorkspaceAccess = typing.Union[
    typing.Literal["admin", "editor", "viewer"], typing.Any
]
