# This file was auto-generated by Fern from our API Definition.

from .types import (
    BodyShareWorkspaceResourceV1WorkspaceResourcesResourceIdSharePostRole,
    BodyUpdateMemberV1WorkspaceMembersPostWorkspaceRole,
)

__all__ = [
    "BodyShareWorkspaceResourceV1WorkspaceResourcesResourceIdSharePostRole",
    "BodyUpdateMemberV1WorkspaceMembersPostWorkspaceRole",
]
