# This file was auto-generated by Fern from our API Definition.

import typing
from ...types.create_twilio_phone_number_request import CreateTwilioPhoneNumberRequest
from ...types.create_sip_trunk_phone_number_request import (
    CreateSipTrunkPhoneNumberRequest,
)

ConversationalAiCreatePhoneNumberRequestBody = typing.Union[
    CreateTwilioPhoneNumberRequest, CreateSipTrunkPhoneNumberRequest
]
