# This file was auto-generated by Fern from our API Definition.

import typing

BodyCreatePodcastV1ProjectsPodcastCreatePostQualityPreset = typing.Union[
    typing.Literal["standard", "high", "highest", "ultra", "ultra_lossless"], typing.Any
]
