# This file was auto-generated by Fern from our API Definition.

import typing

AuthorizationMethod = typing.Union[
    typing.Literal["public", "authorization_header", "signed_url", "shareable_link"],
    typing.Any,
]
