# This file was auto-generated by Fern from our API Definition.

import typing

SubscriptionStatus = typing.Union[
    typing.Literal[
        "trialing",
        "active",
        "incomplete",
        "incomplete_expired",
        "past_due",
        "canceled",
        "unpaid",
        "free",
    ],
    typing.Any,
]
