# This file was auto-generated by Fern from our API Definition.

import typing

TtsConversationalModel = typing.Union[
    typing.Literal["eleven_turbo_v2", "eleven_turbo_v2_5", "eleven_flash_v2", "eleven_flash_v2_5"],
    typing.Any,
]
