# This file was auto-generated by Fern from our API Definition.

import typing

ProjectsAddRequestTargetAudience = typing.Union[
    typing.Literal["children", "young adult", "adult", "all ages"], typing.Any
]
