# This file was auto-generated by Fern from our API Definition.

import typing

SafetyRule = typing.Union[
    typing.Literal[
        "sexual_minors",
        "forget_moderation",
        "extremism",
        "scam_fraud",
        "political",
        "self_harm",
        "illegal_distribution_medical",
        "sexual_adults",
        "unknown",
    ],
    typing.Any,
]
