# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
from .get_conversation_response_model_status import GetConversationResponseModelStatus
import typing
from .conversation_history_transcript_common_model import (
    ConversationHistoryTranscriptCommonModel,
)
from .conversation_history_metadata_common_model import (
    ConversationHistoryMetadataCommonModel,
)
from .conversation_history_analysis_common_model import (
    ConversationHistoryAnalysisCommonModel,
)
from .conversation_initiation_client_data_request_output import (
    ConversationInitiationClientDataRequestOutput,
)
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class GetConversationResponseModel(UncheckedBaseModel):
    agent_id: str
    conversation_id: str
    status: GetConversationResponseModelStatus
    transcript: typing.List[ConversationHistoryTranscriptCommonModel]
    metadata: ConversationHistoryMetadataCommonModel
    analysis: typing.Optional[ConversationHistoryAnalysisCommonModel] = None
    conversation_initiation_client_data: typing.Optional[ConversationInitiationClientDataRequestOutput] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
