# This file was auto-generated by Fern from our API Definition.

from .speech_to_text_convert_request_timestamps_granularity import SpeechToTextConvertRequestTimestampsGranularity

__all__ = ["SpeechToTextConvertRequestTimestampsGranularity"]
