# This file was auto-generated by Fern from our API Definition.

import typing

BodyTextToSpeechStreamingWithTimestampsV1TextToSpeechVoiceIdStreamWithTimestampsPostApplyTextNormalization = (
    typing.Union[typing.Literal["auto", "on", "off"], typing.Any]
)
