# This file was auto-generated by Fern from our API Definition.

import typing

SpeechToTextConvertRequestTimestampsGranularity = typing.Union[typing.Literal["none", "word", "character"], typing.Any]
