# This file was auto-generated by Fern from our API Definition.

from .types import (
    ConversationalAiCreatePhoneNumberRequestBody,
    ConversationalAiGetKnowledgeBaseDocumentByIdResponse,
    ConversationalAiGetKnowledgeBaseDocumentByIdResponse_File,
    ConversationalAiGetKnowledgeBaseDocumentByIdResponse_Url,
)

__all__ = [
    "ConversationalAiCreatePhoneNumberRequestBody",
    "ConversationalAiGetKnowledgeBaseDocumentByIdResponse",
    "ConversationalAiGetKnowledgeBaseDocumentByIdResponse_File",
    "ConversationalAiGetKnowledgeBaseDocumentByIdResponse_Url",
]
